@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -29,23 +30,13 @@
 #pragma hdrstop
 #endif
 
-#ifndef _SWSTYLENAMEMAPPER_HXX
 #include <SwStyleNameMapper.hxx>
-#endif
 #define _SVSTDARR_STRINGSDTOR
 #include <bf_svtools/svstdarr.hxx>
-#ifndef _TOOLS_RESMGR_HXX
 #include <tools/resmgr.hxx>
-#endif
-#ifndef _POOLFMT_HXX
 #include <poolfmt.hxx>
-#endif
-#ifndef _RDIC_HRC
 #include <rcid.hrc>
-#endif
-#ifndef _TOOLS_DEBUG_HXX
 #include <tools/debug.hxx>
-#endif
 namespace binfilter {
 extern ResMgr* pSwResMgr;
 // Initialise UI names to 0
@@ -359,7 +350,7 @@ const struct SwTableEntry NumRuleProgNameTable [] =
 /*N*/ {
 /*N*/ 	NameToIdHash *pHash;
 /*N*/ 	const SvStringsDtor *pStrings;
-/*N*/ 
+/*N*/
 /*N*/ 	switch ( eFlags )
 /*N*/ 	{
 /*N*/ 		case GET_POOLID_TXTCOLL:
@@ -393,7 +384,7 @@ const struct SwTableEntry NumRuleProgNameTable [] =
 /*N*/ 				pStrings = bProgName ? &GetHTMLProgNameArray() : &GetHTMLUINameArray();
 /*N*/ 				for ( nIndex = 0, nId = RES_POOLCOLL_HTML_BEGIN ; nId < RES_POOLCOLL_HTML_END ; nId++,nIndex++ )
 /*N*/ 					(*pHash)[(*pStrings)[nIndex]] = nId;
-/*N*/ 
+/*N*/
 /*N*/ 				if ( bProgName )
 /*N*/ 					pParaProgMap = pHash;
 /*N*/ 				else
@@ -472,155 +463,6 @@ const struct SwTableEntry NumRuleProgNameTable [] =
 /*N*/ 		}
 /*N*/ 		break;
 /*N*/ 	}
-/*N*/ #ifdef _NEED_TO_DEBUG_MAPPING
-/*N*/ 	static sal_Bool bTested = sal_False;
-/*N*/ 	if ( !bTested )
-/*N*/ 	{
-/*N*/ 		bTested = sal_True;
-/*N*/ 		{
-/*N*/ 			for ( sal_uInt16 nIndex = 0, nId = RES_POOLCOLL_TEXT_BEGIN ; nId < RES_POOLCOLL_TEXT_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 			for ( nIndex = 0, nId = RES_POOLCOLL_LISTS_BEGIN ; nId < RES_POOLCOLL_LISTS_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 			for ( nIndex = 0, nId = RES_POOLCOLL_EXTRA_BEGIN ; nId < RES_POOLCOLL_EXTRA_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 			for ( nIndex = 0, nId = RES_POOLCOLL_REGISTER_BEGIN ; nId < RES_POOLCOLL_REGISTER_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 			for ( nIndex = 0, nId = RES_POOLCOLL_DOC_BEGIN ; nId < RES_POOLCOLL_DOC_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 			for ( nIndex = 0, nId = RES_POOLCOLL_HTML_BEGIN ; nId < RES_POOLCOLL_HTML_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 		}
-/*N*/ 		{
-/*N*/ 			for ( sal_uInt16 nIndex = 0, nId = RES_POOLCHR_NORMAL_BEGIN ; nId < RES_POOLCHR_NORMAL_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 			for ( nIndex = 0, nId = RES_POOLCHR_HTML_BEGIN ; nId < RES_POOLCHR_HTML_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 		}
-/*N*/ 		{
-/*N*/ 			for ( sal_uInt16 nIndex=0,nId = RES_POOLFRM_BEGIN ; nId < RES_POOLFRM_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 		}
-/*N*/ 		{
-/*N*/ 			for ( sal_uInt16 nIndex=0,nId = RES_POOLPAGE_BEGIN ; nId < RES_POOLPAGE_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 		}
-/*N*/ 		{
-/*N*/ 			for ( sal_uInt16 nIndex=0,nId = RES_POOLNUMRULE_BEGIN ; nId < RES_POOLNUMRULE_END ; nId++,nIndex++ )
-/*N*/ 			{
-/*N*/ 				String aString, bString;
-/*N*/ 				FillUIName ( nId, aString );
-/*N*/ 				bString = GetProgName ( GET_POOLID_TXTCOLL, aString );
-/*N*/ 				sal_uInt16 nNewId = GetPoolIdFromProgName ( bString, GET_POOLID_TXTCOLL );
-/*N*/ 				FillProgName ( nNewId, aString );
-/*N*/ 				bString = GetUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				nNewId = GetPoolIdFromUIName ( aString, GET_POOLID_TXTCOLL );
-/*N*/ 				if ( nNewId != nId )
-/*N*/ 					*((sal_Int32*)0) = 42;
-/*N*/ 			}
-/*N*/ 		}
-/*N*/ 	}
-/*N*/ #endif
 /*N*/ 	return *pHash;
 /*N*/ }
 // This gets the UI Name from the programmatic name
@@ -646,7 +488,7 @@ const struct SwTableEntry NumRuleProgNameTable [] =
 /*N*/ 	{
 /*N*/ 		// rName isn't in our UI name table...check if it's in the programmatic one
 /*N*/ 		nId = GetPoolIdFromProgName ( rName, eFlags );
-/*N*/ 
+/*N*/
 /*N*/ 		rFillName = rName;
 /*N*/ 		if (nId == USHRT_MAX )
 /*N*/ 		{
@@ -688,7 +530,7 @@ const struct SwTableEntry NumRuleProgNameTable [] =
 /*N*/ {
 /*N*/ 	sal_uInt16 nStt = 0;
 /*N*/ 	const SvStringsDtor* pStrArr = 0;
-/*N*/ 
+/*N*/
 /*N*/ 	switch( (USER_FMT | COLL_GET_RANGE_BITS | POOLGRP_NOCOLLID) & nId )
 /*N*/ 	{
 /*N*/ 	case COLL_TEXT_BITS:
@@ -773,7 +615,7 @@ const struct SwTableEntry NumRuleProgNameTable [] =
 /*N*/ {
 /*N*/ 	sal_uInt16 nStt = 0;
 /*N*/ 	const SvStringsDtor* pStrArr = 0;
-/*N*/ 
+/*N*/
 /*N*/ 	switch( (USER_FMT | COLL_GET_RANGE_BITS | POOLGRP_NOCOLLID) & nId )
 /*N*/ 	{
 /*N*/ 	case COLL_TEXT_BITS:
@@ -867,8 +709,8 @@ const struct SwTableEntry NumRuleProgNameTable [] =
 /*N*/ }
 
 // Get the programmatic Name from the pool ID
-/*N*/ void SwStyleNameMapper::FillProgName ( sal_uInt16 nId, String& rFillName )
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ void SwStyleNameMapper::FillProgName ( sal_uInt16 /*nId*/, String& /*rFillName*/ )
+/*N*/ {DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 // Get the programmatic Name from the pool ID
 /*N*/ const String& SwStyleNameMapper::GetProgName ( sal_uInt16 nId, const String& rName )
@@ -1012,77 +854,77 @@ const struct SwTableEntry NumRuleProgNameTable [] =
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetTextProgNameArray()
 /*N*/ {
 /*N*/ 	return pTextProgNameArray ? *pTextProgNameArray :
-/*N*/ 		   *NewProgNameArray( pTextProgNameArray, TextProgNameTable, 
-/*N*/ 			sizeof ( TextProgNameTable ) / sizeof ( SwTableEntry ) ); 
+/*N*/ 		   *NewProgNameArray( pTextProgNameArray, TextProgNameTable,
+/*N*/ 			sizeof ( TextProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetListsProgNameArray()
 /*N*/ {
-/*N*/ 	return pListsProgNameArray ? *pListsProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pListsProgNameArray, ListsProgNameTable, 
+/*N*/ 	return pListsProgNameArray ? *pListsProgNameArray :
+/*N*/ 		   *NewProgNameArray( pListsProgNameArray, ListsProgNameTable,
 /*N*/ 			sizeof ( ListsProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetExtraProgNameArray()
 /*N*/ {
-/*N*/ 	return pExtraProgNameArray ? *pExtraProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pExtraProgNameArray, ExtraProgNameTable, 
+/*N*/ 	return pExtraProgNameArray ? *pExtraProgNameArray :
+/*N*/ 		   *NewProgNameArray( pExtraProgNameArray, ExtraProgNameTable,
 /*N*/ 			sizeof ( ExtraProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetRegisterProgNameArray()
 /*N*/ {
-/*N*/ 	return pRegisterProgNameArray ? *pRegisterProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pRegisterProgNameArray, RegisterProgNameTable, 
+/*N*/ 	return pRegisterProgNameArray ? *pRegisterProgNameArray :
+/*N*/ 		   *NewProgNameArray( pRegisterProgNameArray, RegisterProgNameTable,
 /*N*/ 			sizeof ( RegisterProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetDocProgNameArray()
 /*N*/ {
-/*N*/ 	return pDocProgNameArray ? *pDocProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pDocProgNameArray, DocProgNameTable, 
+/*N*/ 	return pDocProgNameArray ? *pDocProgNameArray :
+/*N*/ 		   *NewProgNameArray( pDocProgNameArray, DocProgNameTable,
 /*N*/ 			sizeof ( DocProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetHTMLProgNameArray()
 /*N*/ {
-/*N*/ 	return pHTMLProgNameArray ? *pHTMLProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pHTMLProgNameArray, HTMLProgNameTable, 
+/*N*/ 	return pHTMLProgNameArray ? *pHTMLProgNameArray :
+/*N*/ 		   *NewProgNameArray( pHTMLProgNameArray, HTMLProgNameTable,
 /*N*/ 			sizeof ( HTMLProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetFrmFmtProgNameArray()
 /*N*/ {
-/*N*/ 	return pFrmFmtProgNameArray ? *pFrmFmtProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pFrmFmtProgNameArray, FrmFmtProgNameTable, 
+/*N*/ 	return pFrmFmtProgNameArray ? *pFrmFmtProgNameArray :
+/*N*/ 		   *NewProgNameArray( pFrmFmtProgNameArray, FrmFmtProgNameTable,
 /*N*/ 			sizeof ( FrmFmtProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetChrFmtProgNameArray()
 /*N*/ {
-/*N*/ 	return pChrFmtProgNameArray ? *pChrFmtProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pChrFmtProgNameArray, ChrFmtProgNameTable, 
+/*N*/ 	return pChrFmtProgNameArray ? *pChrFmtProgNameArray :
+/*N*/ 		   *NewProgNameArray( pChrFmtProgNameArray, ChrFmtProgNameTable,
 /*N*/ 			sizeof ( ChrFmtProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetHTMLChrFmtProgNameArray()
 /*N*/ {
-/*N*/ 	return pHTMLChrFmtProgNameArray ? *pHTMLChrFmtProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pHTMLChrFmtProgNameArray, HTMLChrFmtProgNameTable, 
+/*N*/ 	return pHTMLChrFmtProgNameArray ? *pHTMLChrFmtProgNameArray :
+/*N*/ 		   *NewProgNameArray( pHTMLChrFmtProgNameArray, HTMLChrFmtProgNameTable,
 /*N*/ 			sizeof ( HTMLChrFmtProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetPageDescProgNameArray()
 /*N*/ {
-/*N*/ 	return pPageDescProgNameArray ? *pPageDescProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pPageDescProgNameArray, PageDescProgNameTable, 
+/*N*/ 	return pPageDescProgNameArray ? *pPageDescProgNameArray :
+/*N*/ 		   *NewProgNameArray( pPageDescProgNameArray, PageDescProgNameTable,
 /*N*/ 			sizeof ( PageDescProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
 /*N*/ const SvStringsDtor& SwStyleNameMapper::GetNumRuleProgNameArray()
 /*N*/ {
-/*N*/ 	return pNumRuleProgNameArray ? *pNumRuleProgNameArray : 
-/*N*/ 		   *NewProgNameArray( pNumRuleProgNameArray, NumRuleProgNameTable, 
+/*N*/ 	return pNumRuleProgNameArray ? *pNumRuleProgNameArray :
+/*N*/ 		   *NewProgNameArray( pNumRuleProgNameArray, NumRuleProgNameTable,
 /*N*/ 			sizeof ( NumRuleProgNameTable ) / sizeof ( SwTableEntry ) );
 /*N*/ }
 
@@ -1142,3 +984,5 @@ const struct SwTableEntry NumRuleProgNameTable [] =
 /*N*/ }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
